/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.type;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.List;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.field.model.TreatmentZone;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * Provides the functionality for creating child nodes for
 * {@link ActivityField}s
 *
 * @author Wytse Visser
 */
public final class ActivityFieldChildFactory extends ChildFactory<TreatmentZone> implements PropertyChangeListener {

    private final ActivityField activityField;

    public ActivityFieldChildFactory(ActivityField activityField) {
        this.activityField = activityField;
        this.activityField.addPropertyChangeListener(this);
    }

    @Override
    protected boolean createKeys(List<TreatmentZone> toPopulate) {
        toPopulate.addAll(activityField.getTreatmentZones());
        return true;
    }

    @Override
    public Node createNodeForKey(TreatmentZone key) {
        return new TreatmentZoneNode(key);
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if (ActivityField.PROP_TREATMENTZONES.equals(evt.getPropertyName())) {
            refresh(true);
        }
    }
}
