/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type;

import javax.swing.JTextArea;
import javax.swing.JTextField;
import nl.cloudfarming.client.field.model.ActivityField;
import org.jdesktop.beansbinding.*;

/**
 * Panel for displaying Activity field properties
 * @author Merij Zengers
 */
public class ActivityFieldDataPanel extends javax.swing.JPanel {

    private ActivityField activityField;
    private Binding nameBinding;
    private BeanProperty nameTextField = BeanProperty.create("text");
    private BeanProperty treatmentZonePropName = BeanProperty.create(ActivityField.PROP_NAME);
    private Binding descriptionBinding;
    private BeanProperty descriptionTextArea = BeanProperty.create("text");
    private BeanProperty treatmentZonePropDescription = BeanProperty.create(ActivityField.PROP_DESCRIPTION);
    
    private BindingGroup activityFieldBindingGroup = new BindingGroup();
    
    /**
     * Creates new form ActivityFieldDataPanel
     */
    public ActivityFieldDataPanel(ActivityField activityField) {
        initComponents();
        this.activityField = activityField;
        assert activityField != null : "this panel cannot be instntiated without a ActivityField";
        initComponents();
        initValues();
        bind();
    }
    
    /**
     * Initiate ActivityField values to values in the ActivityField object
     */
    private void initValues() {
        nameField.setText(activityField.getName());
        descriptionArea.setText(activityField.getDescription());
    }

    /**
     * bind form fields to ActivityField properties
     */
    private void bind() {
        nameBinding = Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
                nameField, nameTextField, activityField, treatmentZonePropName);
        activityFieldBindingGroup.addBinding(nameBinding);
        descriptionBinding = Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
                descriptionArea, descriptionTextArea, activityField, treatmentZonePropDescription);
        activityFieldBindingGroup.addBinding(descriptionBinding);
        activityFieldBindingGroup.bind();
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        nameLabel = new javax.swing.JLabel();
        nameField = new javax.swing.JTextField();
        descriptionLabel = new javax.swing.JLabel();
        descriptionPane = new javax.swing.JScrollPane();
        descriptionArea = new javax.swing.JTextArea();

        nameLabel.setText(org.openide.util.NbBundle.getMessage(ActivityFieldDataPanel.class, "ActivityFieldDataPanel.nameLabel.text")); // NOI18N

        nameField.setText(org.openide.util.NbBundle.getMessage(ActivityFieldDataPanel.class, "ActivityFieldDataPanel.nameField.text")); // NOI18N

        descriptionLabel.setText(org.openide.util.NbBundle.getMessage(ActivityFieldDataPanel.class, "ActivityFieldDataPanel.descriptionLabel.text")); // NOI18N

        descriptionArea.setColumns(20);
        descriptionArea.setRows(5);
        descriptionPane.setViewportView(descriptionArea);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(nameLabel)
                    .addComponent(descriptionLabel))
                .addGap(40, 40, 40)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(descriptionPane, javax.swing.GroupLayout.DEFAULT_SIZE, 355, Short.MAX_VALUE)
                    .addComponent(nameField))
                .addContainerGap(266, Short.MAX_VALUE))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(nameLabel)
                    .addComponent(nameField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(descriptionLabel)
                    .addComponent(descriptionPane, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(185, Short.MAX_VALUE))
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JTextArea descriptionArea;
    private javax.swing.JLabel descriptionLabel;
    private javax.swing.JScrollPane descriptionPane;
    private javax.swing.JTextField nameField;
    private javax.swing.JLabel nameLabel;
    // End of variables declaration//GEN-END:variables

    /**
     * Get the JTextArea which displays {@link ActivityField#description}
     * @return 
     */
    public JTextArea getDescriptionArea() {
        return descriptionArea;
    }

    /**
     * Get the JTextField which displays {@link ActivityField#name}
     * @return 
     */
    public JTextField getNameField() {
        return nameField;
    }

    
}
