/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type;

import java.awt.BorderLayout;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.geoviewer.render.GeometricalsPreviewPanel;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 * Visual tab for ActivityField Displays the geometries of it's TreatmentZones
 *
 * @author Merijn Zengers
 */
@MultiViewElement.Registration(displayName = "#LBL_ActivityField_VISUAL",
iconBase = "nl/cloudfarming/client/field/type/folder_treatmentzones.png",
mimeType = ActivityField.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "ActivityFieldVisual",
position = 2000)
@NbBundle.Messages(value = {
    "LBL_ActivityField_VISUAL=Visual",
    "Title_ActivityField_visual=Activity field visual preview"
})
public class ActivityFieldVisualElement extends JPanel implements MultiViewElement {

    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private final Lookup lookup;
    private final ActivityField activityField;
    private ASBodyPanel contentPanel;

    public ActivityFieldVisualElement(Lookup lookup) {
        this.lookup = lookup;
        activityField = lookup.lookup(ActivityField.class);
        assert activityField != null : "ActivityField should be in the lookup";
    }

    @Override
    public JComponent getVisualRepresentation() {
        if (contentPanel == null) {
            this.setLayout(new BorderLayout());
            contentPanel = new ASBodyPanel(new GeometricalsPreviewPanel(activityField.getGeometricals()));
            contentPanel.setTitle(Bundle.Title_ActivityField_visual());
            contentPanel.setIcon(ImageUtilities.loadImageIcon(activityField.getIconPath(), true));
            add(contentPanel);
        }
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }
    
    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(activityField.getName());
            tc.setDisplayName(activityField.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback mvec) {
        this.callback = mvec;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
