/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type;

import java.awt.Color;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import nl.cloudfarming.client.field.model.OnOff;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.geoviewer.Palette;

/**
 * Convert a TreatmentZone OnOff value to a display color.
 * 
 * @author johan
 */
public class OnOffPalette extends Palette<OnOff> implements PropertyChangeListener {

    public OnOffPalette(TreatmentZone tzn) {
        super(Color.RED);
        setBaseColor(tzn.getValue());
        tzn.addPropertyChangeListener(TreatmentZone.PROP_VALUE, this);
    }
    
    private void setBaseColor(double tznValue) {
        OnOff oo = OnOff.find(tznValue);
        if (oo != null) {
            setBaseColor(getColorForValue(oo));
        }        
    }

    @Override
    public final Color getColorForValue(OnOff value) {
        return value == OnOff.OFF ? Color.WHITE : Color.BLACK;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        setBaseColor((Double)evt.getNewValue());
    }
    
}
