/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.type;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 * MultiViw data element for TreatmentZones
 * @author Merijn Zengers
 */
@MultiViewElement.Registration(displayName = "#LBL_TREATMENTZONE_DATA",
iconBase = "nl/cloudfarming/client/field/type/treatmentzone.png",
mimeType = TreatmentZone.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "TreatmentZoneData",
position = 1000)
@NbBundle.Messages({
    "LBL_TREATMENTZONE_DATA=Data",
    "Label_treatmentzone_data_panel=Treatment zone data",
    "TreatmentZoneDataElement icon=nl/cloudfarming/client/field/type/treatmentzone.png"
})
public class TreatmentZoneDataElement extends JPanel implements MultiViewElement{
    private ASBodyPanel bodyPanel;
    private TreatmentZone treatmentZone;
    private Lookup lookup;
    private transient MultiViewElementCallback callback;
    private NameChangeListener nameChangeListener;
    
    public TreatmentZoneDataElement(Lookup lookup){
        treatmentZone = lookup.lookup(TreatmentZone.class);
        assert treatmentZone != null : "TreatmentZone must be found";
        this.lookup = lookup;
    }
    
    
    @Override
    public JComponent getVisualRepresentation() {
        if(bodyPanel == null){
            TreatmentZoneDataPanel dataPanel = new TreatmentZoneDataPanel(treatmentZone);
            bodyPanel = new ASBodyPanel(dataPanel);
            bodyPanel.setIcon(ImageUtilities.loadImageIcon(Bundle.TreatmentZoneDataElement_icon(), true));
            bodyPanel.setTitle(Bundle.Label_treatmentzone_data_panel());
        }
        return bodyPanel;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return new JToolBar();
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentOpened() {
        nameChangeListener = new NameChangeListener();
        treatmentZone.addPropertyChangeListener(TreatmentZone.PROP_NAME, nameChangeListener);
    }

    @Override
    public void componentClosed() {
        treatmentZone.removePropertyChangeListener(TreatmentZone.PROP_NAME, nameChangeListener);
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback mvec) {
        this.callback = mvec;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
    
    public void updateName() {
        if (callback != null) {
            String name = treatmentZone.getName();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(name);
            tc.setToolTipText(getToolTipText());
        }
    } 
    
    /**
     * Listens to changes on {@link TreatmentZone#PROP_NAME}
     * Updates the topcomponent name
     */
    private class NameChangeListener implements PropertyChangeListener{

        @Override
        public void propertyChange(PropertyChangeEvent pce) {
            if(pce.getPropertyName().equals(TreatmentZone.PROP_NAME)){
                updateName();
            }
        }
        
    }
    
}
