/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.type;

import java.awt.Image;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JTextField;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.util.swing.beanbinding.DoubleConverter;
import nl.cloudfarming.client.util.swing.beanbinding.DoubleValidator;
import org.jdesktop.beansbinding.*;
import org.jdesktop.beansbinding.Binding.SyncFailure;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 * Panel which displays the data of a TreatmentZone
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages({"TreatmentZoneDataPanel area ha=ha"})
public class TreatmentZoneDataPanel extends javax.swing.JPanel implements BindingListener{

    private static final Image ERROR_ICON = ImageUtilities.loadImage("nl/cloudfarming/client/field/type/exclamation.png", true);
    private TreatmentZone treatMentZone;
    private Binding nameBinding;
    private BeanProperty nameTextField = BeanProperty.create("text");
    private BeanProperty treatmentZonePropName = BeanProperty.create(TreatmentZone.PROP_NAME);
    private Binding areaBinding;
    private BeanProperty areaTextField = BeanProperty.create("text");
    private BeanProperty treatmentZonePropArea = BeanProperty.create(TreatmentZone.PROP_AREA_IN_HECTARES);
    private Binding<TreatmentZone, Double, JTextField, String> valueBinding;
    private BeanProperty<JTextField, String> valueTextField = BeanProperty.create("text");
    private BeanProperty<TreatmentZone, Double> treatmentZonePropValue = BeanProperty.create(TreatmentZone.PROP_VALUE);
    private BindingGroup fieldBindingGroup = new BindingGroup();

    /**
     * Creates new form TreatmentZoneDataPanel
     */
    public TreatmentZoneDataPanel(TreatmentZone treatMentZone) {
        this.treatMentZone = treatMentZone;
        assert treatMentZone != null : "this panel cannot be instntiated without a field";
        initComponents();
        initValues();
        bind();
    }

    /**
     * Initiate field values to values in the Field object
     */
    private void initValues() {
        nameField.setText(treatMentZone.getName());
        areaField.setText(String.valueOf(treatMentZone.getAreaInHectares()));
        valueField.setText(String.valueOf(treatMentZone.getValue() != null ? treatMentZone.getValue() : 0));
        exclamationLabel.setVisible(false);
        errorMessageLabel.setVisible(false);
    }

    /**
     * bind form fields to Field properties
     */
    private void bind() {
        nameBinding = Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
                nameField, nameTextField, treatMentZone, treatmentZonePropName);
        fieldBindingGroup.addBinding(nameBinding);
        areaBinding = Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
                areaField, areaTextField, treatMentZone, treatmentZonePropArea);
        fieldBindingGroup.addBinding(areaBinding);
        valueBinding = Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
                treatMentZone, treatmentZonePropValue, valueField, valueTextField);
        valueBinding.setConverter(new DoubleConverter());
        valueBinding.setValidator(new DoubleValidator());
        valueBinding.addBindingListener(this);
        fieldBindingGroup.addBinding(valueBinding);
        fieldBindingGroup.bind();
        
    }
    
    @Override
    public void bindingBecameBound(Binding binding) {
    }

    @Override
    public void bindingBecameUnbound(Binding binding) {
    }

    @Override
    public void syncFailed(Binding binding, SyncFailure failure) {
        errorMessageLabel.setText(failure.getValidationResult().getDescription());
        errorMessageLabel.setVisible(true);
        exclamationLabel.setVisible(true);
    }

    @Override
    public void synced(Binding binding) {
        errorMessageLabel.setVisible(false);
        exclamationLabel.setVisible(false);
    }

    @Override
    public void sourceChanged(Binding binding, PropertyStateEvent event) {
    }

    @Override
    public void targetChanged(Binding binding, PropertyStateEvent event) {
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        areaLabel = new javax.swing.JLabel();
        nameLabel = new javax.swing.JLabel();
        valueField = new javax.swing.JTextField();
        areaUnitLabel = new javax.swing.JLabel();
        nameField = new javax.swing.JTextField();
        areaField = new javax.swing.JLabel();
        valueLabel = new javax.swing.JLabel();
        exclamationLabel = new javax.swing.JLabel();
        errorMessageLabel = new javax.swing.JLabel();

        areaLabel.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.areaLabel.text")); // NOI18N

        nameLabel.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.nameLabel.text")); // NOI18N

        areaUnitLabel.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.areaUnitLabel.text")); // NOI18N

        nameField.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.nameField.text")); // NOI18N

        areaField.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.areaField.text")); // NOI18N
        areaField.setBorder(javax.swing.BorderFactory.createEmptyBorder(1, 5, 1, 1));

        valueLabel.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.valueLabel.text")); // NOI18N

        exclamationLabel.setIcon(new ImageIcon(ERROR_ICON));
        exclamationLabel.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.exclamationLabel.text")); // NOI18N

        errorMessageLabel.setText(org.openide.util.NbBundle.getMessage(TreatmentZoneDataPanel.class, "TreatmentZoneDataPanel.errorMessageLabel.text")); // NOI18N

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(nameLabel)
                    .addComponent(areaLabel)
                    .addComponent(valueLabel))
                .addGap(8, 8, 8)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addGap(74, 74, 74)
                        .addComponent(exclamationLabel)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(errorMessageLabel))
                    .addGroup(layout.createSequentialGroup()
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                            .addGroup(layout.createSequentialGroup()
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(valueField, javax.swing.GroupLayout.PREFERRED_SIZE, 358, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
                                .addGap(63, 63, 63)
                                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                                    .addComponent(areaField, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 358, Short.MAX_VALUE)
                                    .addComponent(nameField, javax.swing.GroupLayout.Alignment.LEADING))))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(areaUnitLabel)))
                .addContainerGap(43, Short.MAX_VALUE))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(nameLabel)
                    .addComponent(nameField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(areaLabel)
                    .addComponent(areaField)
                    .addComponent(areaUnitLabel))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(valueLabel)
                    .addComponent(valueField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(errorMessageLabel)
                    .addComponent(exclamationLabel))
                .addContainerGap(226, Short.MAX_VALUE))
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel areaField;
    private javax.swing.JLabel areaLabel;
    private javax.swing.JLabel areaUnitLabel;
    private javax.swing.JLabel errorMessageLabel;
    private javax.swing.JLabel exclamationLabel;
    private javax.swing.JTextField nameField;
    private javax.swing.JLabel nameLabel;
    private javax.swing.JTextField valueField;
    private javax.swing.JLabel valueLabel;
    // End of variables declaration//GEN-END:variables

    /**
     * Get the JTextField for Area
     *
     * @return
     */
    public JLabel getAreaField() {
        return areaField;
    }

    /**
     * Get the JTextField for name
     *
     * @return
     */
    public JTextField getNameField() {
        return nameField;
    }

    /**
     * Get the JTextfield for value
     *
     * @return
     */
    public JTextField getValueField() {
        return valueField;
    }
}
