/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.type.wizard;

import java.awt.BorderLayout;
import java.util.List;
import javax.swing.*;
import nl.cloudfarming.client.geoviewer.Geometrical;
import nl.cloudfarming.client.geoviewer.render.GeometricalsPreviewPanel;
import org.openide.awt.Mnemonics;
import org.openide.util.NbBundle;

/**
 * 
 * @author Maciek
 */
@NbBundle.Messages({
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection=Selection:",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_from_farm=From farm:",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_caption=Please review your selection before pressing finish.",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection_preview=Selection preview:",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_summary_text=Please review your selection before pressing finish.",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_invalid_state=No items selected. Please go back and select one item.", 
    "GeometricalTaskObjectSelectVisualSummaryPanel_panel_name=Summary"
})
public final class GeometricalSelectSummaryPanel extends JPanel {

    private JLabel labelSelection;
    private JLabel labelFromFarm;
    private JLabel selectedFarm;
    private JLabel labelCaption;
    private JLabel labelSelectionPreview;
    private JList listSelection;
    private JScrollPane scrollPaneSelection;
    private JPanel previewPanel;

    /**
     * Creates new form GeometricalTaskObjectSelectVisualSummaryPanel
     */
    public GeometricalSelectSummaryPanel() {
        initComponents();
    }

    @Override
    public String getName() {
        return Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_panel_name();
    }

    /**
     * Method will reset the selectionlist and refresh the previewpanel
     * @param geometricals 
     */
    protected void setGeometricals(List<Geometrical> geometricals){
        
        // Refresh SelectionList
        List<String> geometricalPaths = GeometricalSelectUtil.getGeometricalPaths(geometricals);
        if (geometricalPaths != null) {
            listSelection.removeAll();
            listSelection.setListData(geometricalPaths.toArray());
        }
        
        // Refresh previewPanel
        previewPanel.setLayout(new BorderLayout());
        previewPanel.removeAll();
        previewPanel.add(new GeometricalsPreviewPanel(geometricals));
        previewPanel.validate();
        previewPanel.repaint();
        previewPanel.setVisible(true);
    }
    
    protected void setSelectedProjectPath(String projectPath) {
        selectedFarm.setText(projectPath);
    }

    protected void setValid(boolean valid) {
        labelSelection.setVisible(valid);
        listSelection.setVisible(valid);
        labelFromFarm.setVisible(valid);
        selectedFarm.setVisible(valid);
        labelSelectionPreview.setVisible(valid);
        previewPanel.setVisible(valid);
        showCaptionText(valid);
    }

    private void showCaptionText(boolean valid) {
        if (valid) {
            labelCaption.setText(Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_summary_text());
        } else {
            labelCaption.setText(Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_invalid_state());
        }
    }
        
    /**
     * This method is called from within the constructor to initialize the form.
     */
    private void initComponents() {

        labelSelection = new JLabel();
        labelFromFarm = new JLabel();
        selectedFarm = new JLabel();
        labelCaption = new JLabel();
        labelSelectionPreview = new JLabel();
        
        previewPanel = new JPanel();
        scrollPaneSelection = new JScrollPane();
        listSelection = new JList();
        scrollPaneSelection.setViewportView(listSelection);

        Mnemonics.setLocalizedText(labelSelection, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection()); // NOI18N
        Mnemonics.setLocalizedText(labelFromFarm, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_from_farm()); // NOI18N
        Mnemonics.setLocalizedText(labelCaption, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_caption()); // NOI18N
        Mnemonics.setLocalizedText(labelSelectionPreview, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection_preview()); // NOI18N

        GroupLayout previewPanelLayout = new GroupLayout(previewPanel);
        previewPanel.setLayout(previewPanelLayout);
        previewPanelLayout.setHorizontalGroup(
                previewPanelLayout.createParallelGroup(GroupLayout.Alignment.LEADING).addGap(0, 359, Short.MAX_VALUE));
        previewPanelLayout.setVerticalGroup(
                previewPanelLayout.createParallelGroup(GroupLayout.Alignment.LEADING).addGap(0, 239, Short.MAX_VALUE));

        GroupLayout layout = new GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
                layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addContainerGap().addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(GroupLayout.Alignment.TRAILING, layout.createSequentialGroup().addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addComponent(labelSelection).addGap(0, 0, Short.MAX_VALUE)).addComponent(scrollPaneSelection, GroupLayout.PREFERRED_SIZE, 0, Short.MAX_VALUE)).addGap(18, 18, 18).addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(previewPanel, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE).addComponent(labelSelectionPreview))).addGroup(layout.createSequentialGroup().addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(labelCaption).addGroup(layout.createSequentialGroup().addComponent(labelFromFarm).addPreferredGap(LayoutStyle.ComponentPlacement.RELATED).addComponent(selectedFarm))).addGap(0, 136, Short.MAX_VALUE))).addContainerGap()));
        layout.setVerticalGroup(
                layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addContainerGap().addComponent(labelCaption).addGap(58, 58, 58).addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(labelFromFarm).addComponent(selectedFarm)).addPreferredGap(LayoutStyle.ComponentPlacement.RELATED).addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(labelSelectionPreview).addComponent(labelSelection)).addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED).addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(previewPanel, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE).addComponent(scrollPaneSelection)).addContainerGap()));
    }
}