/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type.wizard;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;
import javax.swing.AbstractAction;
import javax.swing.JComponent;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.field.model.Field;
import org.openide.DialogDisplayer;
import org.openide.WizardDescriptor;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.awt.ActionRegistration;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@NbBundle.Messages("NewActivityFieldAction name=New activity field")
@ActionID(category = "Field", id = "nl.cloudfarming.client.field.type.wizard.NewActivityFieldAction")
@ActionRegistration(iconBase = "nl/cloudfarming/client/field/type/folder_treatmentzones.png", displayName = "#NewActivityFieldAction name")
@ActionReferences({
    @ActionReference(path = "Actions/Field", position = 0)
})
public class NewActivityFieldAction extends AbstractAction implements ActionListener {

    private final Field field;

    public NewActivityFieldAction(Field field) {
        putValue(NAME, Bundle.new_activity_field_wizard_title());
        this.field = field;
        verifyFieldGeometry(field);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        List<WizardDescriptor.Panel<WizardDescriptor>> panels = new ArrayList<>();
        panels.add(new NewActivityFieldWizardPanel(field));
        String[] steps = new String[panels.size()];
        for (int i = 0; i < panels.size(); i++) {
            Component c = panels.get(i).getComponent();
            // Default step name to component name of panel.
            steps[i] = c.getName();
            if (c instanceof JComponent) { // assume Swing components
                JComponent jc = (JComponent) c;
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_SELECTED_INDEX, i);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_DATA, steps);
                jc.putClientProperty(WizardDescriptor.PROP_AUTO_WIZARD_STYLE, true);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_DISPLAYED, true);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_NUMBERED, true);
            }
        }
        WizardDescriptor wiz = new WizardDescriptor(new WizardDescriptor.ArrayIterator<>(panels));
        // {0} will be replaced by WizardDesriptor.Panel.getComponent().getName()
        wiz.setTitleFormat(new MessageFormat("{0}"));
        wiz.setTitle(Bundle.new_activity_field_wizard_title());
        if (DialogDisplayer.getDefault().notify(wiz) == WizardDescriptor.FINISH_OPTION) {
            String activityFieldName = wiz.getProperty(NewActivityFieldWizardPanel.PROP_ACTIVITY_FIELD_NAME).toString();
            ActivityField activityField = new ActivityField(field.getURI(), activityFieldName, field.getGeometry());
            activityField.setDescription(wiz.getProperty(NewActivityFieldWizardPanel.PROP_ACTIVITY_FIELD_DESCRIPTION).toString());
            field.addActivityField(activityField);
        }
    }

    /**
     * Disable this action if the selected field does not have a geometry.
     *
     * @param field The field the user wishes to add an activityField to
     */
    private void verifyFieldGeometry(Field field) {
        if (field.getGeometry() == null) {
            setEnabled(false);
        }
    }
}
