/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type.wizard;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.HashSet;
import java.util.Set;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.field.type.FieldDataPanel;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.WizardValidationException;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

@NbBundle.Messages({
    "new field wizard title=New field",
    "new field wizard data step name=Enter field data"
})
public class NewFieldWizardPanel implements WizardDescriptor.Panel<WizardDescriptor>, KeyListener {

    static final String PROP_FIELD = "field";
    private FieldDataPanel visualComponent;
    private ASBodyPanel component;
    private final Set<ChangeListener> listeners = new HashSet<>(1);
    private final Field field;
    private static final String ICON = "nl/cloudfarming/client/field/type/field32.png";
    private WizardDescriptor wizardDescriptor;

    public NewFieldWizardPanel(Project project) {
        EnterpriseIdProvider eip = project.getLookup().lookup(EnterpriseIdProvider.class);
        this.field = new Field(eip);
    }

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public ASBodyPanel getComponent() {
        if (component == null) {
            visualComponent = new FieldDataPanel(field);
            visualComponent.getNameField().addKeyListener(this);
            component = new ASBodyPanel(visualComponent);
            component.setTitle(Bundle.new_field_wizard_title());
            component.setIcon(ImageUtilities.loadImageIcon(ICON, false));
            component.setName(Bundle.new_field_wizard_data_step_name());
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
        // If you have context help:
        // return new HelpCtx("help.key.here");
    }

    @Override
    public boolean isValid() {
        String errorMsg = null;
        String userInput = visualComponent.getNameField().getText().trim();
        try {
            validate(userInput);
        } catch (WizardValidationException e) {
            errorMsg = e.getLocalizedMessage();
        } finally {
            wizardDescriptor.putProperty(WizardDescriptor.PROP_ERROR_MESSAGE, errorMsg);
            return errorMsg == null;
        }
    }

    @Override
    public void addChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.add(l);
        }
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.remove(l);
        }
    }

    protected final void fireChangeEvent() {
        Set<ChangeListener> ls;
        synchronized (listeners) {
            ls = new HashSet<>(listeners);
        }
        ChangeEvent ev = new ChangeEvent(this);
        for (ChangeListener l : ls) {
            l.stateChanged(ev);
        }
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
        wizardDescriptor = wiz;
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
        wiz.putProperty(PROP_FIELD, field);
    }

    public void validate(String userInput) throws WizardValidationException {
    }

    @Override
    public void keyTyped(KeyEvent e) {
    }

    @Override
    public void keyPressed(KeyEvent e) {
    }

    @Override
    public void keyReleased(KeyEvent e) {
        isValid();
        fireChangeEvent();
    }
}